@@ -1,29 +1,30 @@
 #!/usr/bin/env bash
 
-set -e
+set -eu
 
-[ $# == 1 ] || { echo "usage: $0 version" && exit 1; }
+if [[ $# != 1 ]]; then
+	echo "usage: $0 vX.Y.Z"
+	exit 1
+fi
 
 VER=$1
 
-[[ "$VER" =~ ^v[[:digit:]]+\.[[:digit:]]+\.[[:digit:]]+$ ]] || {
+if ! [[ "$VER" =~ ^v[[:digit:]]+\.[[:digit:]]+\.[[:digit:]]+$ ]]; then
 	echo "malformed version: \"$VER\""
-	exit 2
-}
+	exit 1
+fi
 
-if test -n "$(git ls-files --others | \
-	grep --invert-match '\(vendor\|build/operator-sdk-v.\+\)')";
-then
+if git ls-files --others  --exclude-standard | grep -Ev 'build/operator-sdk-v.+'; then
 	echo "directory has untracked files"
 	exit 1
 fi
 
-if ! $(git diff-index --quiet HEAD --); then
+if ! git diff-index --quiet HEAD --; then
 	echo "directory has uncommitted files"
 	exit 1
 fi
 
-GO_VER="1.12"
+GO_VER="1.13"
 if ! go version | cut -d" " -f3 | grep -q "$GO_VER"; then
 	echo "must compile binaries with Go compiler version v${GO_VER}"
 	exit 1
@@ -37,9 +38,9 @@ if [[ "$VER" != "$CURR_VER" ]]; then
 	exit 1
 fi
 
-GO_GOMOD="internal/pkg/scaffold/go_mod.go"
-ANS_GOMOD="internal/pkg/scaffold/ansible/go_mod.go"
-HELM_GOMOD="internal/pkg/scaffold/helm/go_mod.go"
+GO_GOMOD="internal/scaffold/go_mod.go"
+ANS_GOMOD="internal/scaffold/ansible/go_mod.go"
+HELM_GOMOD="internal/scaffold/helm/go_mod.go"
 CURR_VER_GO_GOMOD="$(sed -E -n -r 's|.*operator-sdk ([^ \t\n]+).*|\1|p' "$GO_GOMOD" | tail -1 | tr -d ' \t\n')"
 if [[ "$VER" != "$CURR_VER_GO_GOMOD" ]]; then
 	echo "go.mod 'replace' entry version is not set correctly in $GO_GOMOD"
@@ -56,34 +57,16 @@ if [[ "$VER" != "$CURR_VER_HELM_GOMOD" ]]; then
 	exit 1
 fi
 
-GO_DEP="internal/pkg/scaffold/gopkgtoml.go"
-ANS_DEP="internal/pkg/scaffold/ansible/gopkgtoml.go"
-HELM_DEP="internal/pkg/scaffold/helm/gopkgtoml.go"
-INSTALL_GUIDE_FILE="doc/user/install-operator-sdk.md"
-CURR_VER_GO_DEP="$(sed -nr 's/.*".*v(.+)".*#osdk_version_annotation/v\1/p' "$GO_DEP" | tr -d ' \t\n')"
-if [[ "$VER" != "$CURR_VER_GO_DEP" ]]; then
-	echo "Gopkg.toml 'constraint' version is not set correctly in $GO_DEP"
-	exit 1
-fi
-CURR_VER_ANS_DEP="$(sed -nr 's/.*".*v(.+)".*#osdk_version_annotation/v\1/p' "$ANS_DEP" | tr -d ' \t\n')"
-if [[ "$VER" != "$CURR_VER_ANS_DEP" ]]; then
-	echo "Gopkg.toml 'constraint' version is not set correctly in $ANS_DEP"
-	exit 1
-fi
-
-CURR_VER_HELM_DEP="$(sed -nr 's/.*".*v(.+)".*#osdk_version_annotation/v\1/p' "$HELM_DEP" | tr -d ' \t\n')"
-if [[ "$VER" != "$CURR_VER_HELM_DEP" ]]; then
-	echo "Gopkg.toml 'constraint' version is not set correctly in $HELM_DEP"
-	exit 1
-fi
-
+INSTALL_GUIDE_FILE="website/content/en/docs/install-operator-sdk.md"
 CURR_VER_INSTALL_GUIDE_FILE="$(sed -nr 's/.*RELEASE_VERSION=(.+)/\1/p' "$INSTALL_GUIDE_FILE" | tr -d ' \t\n')"
 if [[ "$VER" != "$CURR_VER_INSTALL_GUIDE_FILE" ]]; then
 	echo "version '$VER' is not set correctly in $INSTALL_GUIDE_FILE"
-    exit 1
+	exit 1
 fi
-git tag --sign --message "Operator SDK $VER" "$VER"
 
+# Tag the release commit and verify its tag.
+git tag --sign --message "Operator SDK $VER" "$VER"
 git verify-tag --verbose "$VER"
 
-make release
+# Run the release builds.
+make release V=1
